Class: GovDelivery::TMS::FromAddress

Inherits:
Object
  • Object
show all
Includes:
InstanceResource
Defined in:
lib/govdelivery/tms/resource/from_address.rb

Overview

FromAddress is an email address, associated response addresses (reply to, error to), and a display name that is used when sending an email via TMS. All messages sent via TMS must have a FromAddress, which can be set via or via a template. If neither is set with a message is sent, then the account’s default FromAddress will be used.

This resource is read-only.

To add more FromAddresses to your account, please contact your CSC.

Instance Attribute Summary collapse

Attributes included from InstanceResource

#response

Method Summary

Methods included from InstanceResource

included

Instance Attribute Details

#bounce_emailString

Email address that will be used for the Errors-To header

Returns:

  • (String)

    the current value of bounce_email



17
18
19
# File 'lib/govdelivery/tms/resource/from_address.rb', line 17

def bounce_email
  @bounce_email
end

#created_atObject (readonly)

Returns the value of attribute created_at.



1
2
3
# File 'lib/govdelivery/tms/resource/from_address.rb', line 1

def created_at
  @created_at
end

#from_emailString

Email address that a message will be sent from

Returns:

  • (String)

    the current value of from_email



17
18
19
# File 'lib/govdelivery/tms/resource/from_address.rb', line 17

def from_email
  @from_email
end

#from_nameString

Display name of the sender of a message

Returns:

  • (String)

    the current value of from_name



17
18
19
# File 'lib/govdelivery/tms/resource/from_address.rb', line 17

def from_name
  @from_name
end

#idObject (readonly)

Returns the value of attribute id.



1
2
3
# File 'lib/govdelivery/tms/resource/from_address.rb', line 1

def id
  @id
end

#is_defaultBoolean

Indicates if the FromAddress is the account’s default FromAddress

Returns:

  • (Boolean)

    the current value of is_default



17
18
19
# File 'lib/govdelivery/tms/resource/from_address.rb', line 17

def is_default
  @is_default
end

#reploy_to_emailStirng

Email address that will be used for the Reply-To header

Returns:

  • (Stirng)

    the current value of reploy_to_email



17
18
19
# File 'lib/govdelivery/tms/resource/from_address.rb', line 17

def reploy_to_email
  @reploy_to_email
end