Class: GovDelivery::TMS::MessageType

Inherits:
Object
  • Object
show all
Includes:
InstanceResource
Defined in:
lib/govdelivery/tms/resource/message_type.rb

Overview

A MessageType is a like a tag that can be attached to an EmailTemplate or an EmailMessage. It is included in encoded links and can be used as a Segmentation filter.

Instance Attribute Summary collapse

Attributes included from InstanceResource

#response

Method Summary

Methods included from InstanceResource

included

Instance Attribute Details

#codeString

The unique identifier of the MessageType.

Returns:

  • (String)

    the current value of code



10
11
12
# File 'lib/govdelivery/tms/resource/message_type.rb', line 10

def code
  @code
end

#labelString

User facing description

Returns:

  • (String)

    the current value of label



10
11
12
# File 'lib/govdelivery/tms/resource/message_type.rb', line 10

def label
  @label
end