Exception: GovDelivery::TMS::Request::InProgress
- Inherits:
-
StandardError
- Object
- StandardError
- GovDelivery::TMS::Request::InProgress
- Defined in:
- lib/govdelivery/tms/errors.rb
Overview
Raised when a recipient list is still being constructed and a request is made to view the recipient list for a message.