Class: GovDelivery::TMS::FromAddress
- Inherits:
-
Object
- Object
- GovDelivery::TMS::FromAddress
- Includes:
- InstanceResource
- Defined in:
- lib/govdelivery/tms/resource/from_address.rb
Overview
FromAddress is an email address, associated response addresses (reply to, error to), and a display name that is used when sending an email via TMS. All messages sent via TMS must have a FromAddress, which can be set via or via a template. If neither is set with a message is sent, then the account’s default FromAddress will be used.
This resource is read-only.
To add more FromAddresses to your account, please contact your CSC.
Instance Attribute Summary collapse
-
#bounce_email ⇒ String
Email address that will be used for the Errors-To header.
-
#created_at ⇒ Object
readonly
Returns the value of attribute created_at.
-
#from_email ⇒ String
Email address that a message will be sent from.
-
#from_name ⇒ String
Display name of the sender of a message.
-
#id ⇒ Object
readonly
Returns the value of attribute id.
-
#is_default ⇒ Boolean
Indicates if the FromAddress is the account’s default FromAddress.
-
#reploy_to_email ⇒ Stirng
Email address that will be used for the Reply-To header.
Attributes included from InstanceResource
Method Summary
Methods included from InstanceResource
Instance Attribute Details
#bounce_email ⇒ String
Email address that will be used for the Errors-To header
17 18 19 |
# File 'lib/govdelivery/tms/resource/from_address.rb', line 17 def bounce_email @bounce_email end |
#created_at ⇒ Object (readonly)
Returns the value of attribute created_at.
1 2 3 |
# File 'lib/govdelivery/tms/resource/from_address.rb', line 1 def created_at @created_at end |
#from_email ⇒ String
Email address that a message will be sent from
17 18 19 |
# File 'lib/govdelivery/tms/resource/from_address.rb', line 17 def from_email @from_email end |
#from_name ⇒ String
Display name of the sender of a message
17 18 19 |
# File 'lib/govdelivery/tms/resource/from_address.rb', line 17 def from_name @from_name end |
#id ⇒ Object (readonly)
Returns the value of attribute id.
1 2 3 |
# File 'lib/govdelivery/tms/resource/from_address.rb', line 1 def id @id end |
#is_default ⇒ Boolean
Indicates if the FromAddress is the account’s default FromAddress
17 18 19 |
# File 'lib/govdelivery/tms/resource/from_address.rb', line 17 def is_default @is_default end |
#reploy_to_email ⇒ Stirng
Email address that will be used for the Reply-To header
17 18 19 |
# File 'lib/govdelivery/tms/resource/from_address.rb', line 17 def reploy_to_email @reploy_to_email end |