Class: GovDelivery::TMS::MessageType
- Inherits:
-
Object
- Object
- GovDelivery::TMS::MessageType
- Includes:
- InstanceResource
- Defined in:
- lib/govdelivery/tms/resource/message_type.rb
Overview
A MessageType is a like a tag that can be attached to an EmailTemplate or an EmailMessage. It is included in encoded links and can be used as a Segmentation filter.
Instance Attribute Summary collapse
-
#code ⇒ String
The unique identifier of the MessageType.
-
#label ⇒ String
User facing description.
Attributes included from InstanceResource
Method Summary
Methods included from InstanceResource
Instance Attribute Details
#code ⇒ String
The unique identifier of the MessageType.
10 11 12 |
# File 'lib/govdelivery/tms/resource/message_type.rb', line 10 def code @code end |
#label ⇒ String
User facing description
10 11 12 |
# File 'lib/govdelivery/tms/resource/message_type.rb', line 10 def label @label end |